@@ -24,8 +24,7 @@ class WTSpawnController():
                      "sleep-increment": .125,  # Incremental sleep value
                      "expire": -1,  # Default: no expiration
                      "error": self.default_error,  # Default error callback,
-                     "hosts": ["localhost"],  # Where to run the command. Default locally
-                     "hooks": {}  # hooks and their parms.  Example: hooks: {hook_function: {parmA: "blah", parmB: "bleck"}}
+                     "hosts": ["localhost"]  # Where to run the command. Default locally
                      }
 
     # clean out any promises that have resolved
@@ -96,26 +95,4 @@ class WTSpawnController():
     # Merge in parameters settings
     def set_parms(self, parms):
         for k, v in parms.items():
-            self.args[k] = v
-
-
-    # Add a new hook.  If command patter already exists, add the functions to it otherwise create it.
-    def add_hook(self, pattern, function, parms):
-        if pattern in self.args['hooks']:
-            if function in  self.args["hooks"][pattern]:
-                self.args["hooks"][pattern][function] = parms
-            else:
-                self.args["hooks"][pattern].update({function: parms})
-        else:
-            self.args["hooks"].update({pattern : {function: parms}})
-
-    
-    # Remove all hooks
-    def remove_hooks(self, pattern = None):
-        if not pattern:
-            self.args["hooks"] = {}
-        else:
-            if pattern in self.args["hooks"]:
-                del self.args["hooks"][pattern]
-        
-        
\ No newline at end of file
+            self.args[k] = v
\ No newline at end of file
